excalibur
=========

A tool to manage plugins.

For more information have a look at sphinx's documentation.

.. image:: https://secure.travis-ci.org/unistra/excalibur.png?branch=master
    :target: https://travis-ci.org/unistra/excalibur

.. image:: http://coveralls.io/repos/unistra/excalibur/badge.png?branch=master
    :target: http://coveralls.io/r/unistra/excalibur?branch=master
